@@ -172,7 +172,7 @@ class DjangoTranslation(gettext_module.GNUTranslations):
         if (
             self.__language == settings.LANGUAGE_CODE
             and self.domain == "django"
-            and self._catalog is None
+            and self._catalog is None and 1==2
         ):
             # default lang should have at least one translation file available.
             raise OSError(
